@@ -1,5 +1,9 @@
 #!/usr/bin/perl
 
+=head1 NAME
+    C4::SIP::SIPServer
+=cut
+
 package C4::SIP::SIPServer;
 
 use strict;
@@ -8,17 +12,17 @@ use FindBin qw($Bin);
 use lib "$Bin";
 use Net::Server::PreFork;
 use IO::Socket::INET;
-use Socket qw(:DEFAULT :crlf TCP_KEEPIDLE TCP_KEEPINTVL IPPROTO_TCP);
+use Socket       qw(:DEFAULT :crlf TCP_KEEPIDLE TCP_KEEPINTVL IPPROTO_TCP);
 use Scalar::Util qw(blessed);
 require UNIVERSAL::require;
 
 use C4::Context;
-use C4::SIP::Sip qw(siplog);
+use C4::SIP::Sip            qw(siplog);
 use C4::SIP::Sip::Constants qw(:all);
 use C4::SIP::Sip::Configuration;
 use C4::SIP::Sip::Checksum qw(checksum verify_cksum);
-use C4::SIP::Sip::MsgType qw( handle login_core );
-use C4::SIP::Logger qw(set_logger);
+use C4::SIP::Sip::MsgType  qw( handle login_core );
+use C4::SIP::Logger        qw(set_logger);
 
 use Koha::Caches;
 use Koha::Logger;
@@ -28,15 +32,14 @@ tie *STDERR, "C4::SIP::Trapper";
 
 use base qw(Net::Server::PreFork);
 
-use constant LOG_SIP => "local6"; # Local alias for the logging facility
-
+use constant LOG_SIP => "local6";    # Local alias for the logging facility
 
 set_logger( Koha::Logger->get( { interface => 'sip' } ) );
 
 #
 # Main  # not really, since package SIPServer
 #
-# FIXME: Is this a module or a script?  
+# FIXME: Is this a module or a script?
 # A script with no MAIN namespace?
 # A module that takes command line args?
 
@@ -52,13 +55,13 @@ my %transports = (
 # Read configuration
 #
 my $config = C4::SIP::Sip::Configuration->new( $ARGV[0] );
-my @parms;
+my @params;
 
 #
 # Ports to bind
 #
-foreach my $svc (keys %{$config->{listeners}}) {
-    push @parms, "port=" . $svc;
+foreach my $svc ( keys %{ $config->{listeners} } ) {
+    push @params, "port=" . $svc;
 }
 
 #
@@ -70,31 +73,31 @@ foreach my $svc (keys %{$config->{listeners}}) {
 #
 # The IDENT is determined by config file 'server-params' arguments
 
-
 #
 # Server Management: set parameters for the Net::Server::PreFork
 # module.  The module silently ignores parameters that it doesn't
 # recognize, and complains about invalid values for parameters
 # that it does.
 #
-if (defined($config->{'server-params'})) {
-    while (my ($key, $val) = each %{$config->{'server-params'}}) {
-        push @parms, $key . '=' . $val;
+if ( defined( $config->{'server-params'} ) ) {
+    while ( my ( $key, $val ) = each %{ $config->{'server-params'} } ) {
+        push @params, $key . '=' . $val;
     }
 }
+
 # Add user and group to prevent warn from Net::Server.
-push @parms, 'user=' . $>;
-push @parms, 'group=' . $>;
+push @params, 'user=' . $>;
+push @params, 'group=' . $>;
 
 #
 # This is the main event.
-__PACKAGE__ ->run(@parms);
+__PACKAGE__->run(@params);
 
 #
 # Server
 #
 
-=head3 options
+=head2 options
 
 As per Net::Server documentation, override "options" to provide your own
 custom options to the Net::Server* object. This allows us to use the Net::Server
@@ -121,7 +124,7 @@ sub options {
     $template->{'custom_tcp_keepalive_intvl'} = \$prop->{'custom_tcp_keepalive_intvl'};
 }
 
-=head3 post_configure_hook
+=head2 post_configure_hook
 
 As per Net::Server documentation, this method validates our custom configuration.
 
@@ -149,7 +152,7 @@ sub post_configure_hook {
     }
 }
 
-=head3 post_accept_hook
+=head2 post_accept_hook
 
 This hook occurs after the client connection socket is created, which gives
 us an opportunity to enable support for TCP keepalives using the SO_KEEPALIVE
@@ -220,7 +223,7 @@ sub post_accept_hook {
 sub process_request {
     my $self = shift;
     my $service;
-    my ($sockaddr, $port, $proto);
+    my ( $sockaddr, $port, $proto );
     my $transport;
 
     $self->{config} = $config;
@@ -228,8 +231,8 @@ sub process_request {
     # Flushing L1 to make sure the request will be processed using the correct data
     Koha::Caches->flush_L1_caches();
 
-    $self->{account} = undef;  # Clear out the account from the last request, it may be different
-    $self->{logger} = set_logger( Koha::Logger->get( { interface => 'sip' } ) );
+    $self->{account} = undef;    # Clear out the account from the last request, it may be different
+    $self->{logger}  = set_logger( Koha::Logger->get( { interface => 'sip' } ) );
 
     # Flush previous MDCs to prevent accidentally leaking incorrect MDC-entries
     Koha::Logger->clear_mdc();
@@ -238,26 +241,29 @@ sub process_request {
 
     # Check if socket connection is IPv6 before resolving address
     my $family = Socket::sockaddr_family($sockname);
-    if ($family == AF_INET6) {
-      ($port, $sockaddr) = sockaddr_in6($sockname);
-      $sockaddr = Socket::inet_ntop(AF_INET6, $sockaddr);
+    if ( $family == AF_INET6 ) {
+        ( $port, $sockaddr ) = sockaddr_in6($sockname);
+        $sockaddr = Socket::inet_ntop( AF_INET6, $sockaddr );
     } else {
-      ($port, $sockaddr) = sockaddr_in($sockname);
-      $sockaddr = inet_ntoa($sockaddr);
+        ( $port, $sockaddr ) = sockaddr_in($sockname);
+        $sockaddr = inet_ntoa($sockaddr);
     }
     $proto = $self->{server}->{client}->NS_proto();
 
-    $self->{service} = $config->find_service($sockaddr, $port, $proto);
+    $self->{service} = $config->find_service( $sockaddr, $port, $proto );
 
-    if (!defined($self->{service})) {
-        siplog("LOG_ERR", "process_request: Unknown recognized server connection: %s:%s/%s", $sockaddr, $port, $proto);
+    if ( !defined( $self->{service} ) ) {
+        siplog(
+            "LOG_ERR", "process_request: Unknown recognized server connection: %s:%s/%s", $sockaddr, $port,
+            $proto
+        );
         die "process_request: Bad server connection";
     }
 
-    $transport = $transports{$self->{service}->{transport}};
+    $transport = $transports{ $self->{service}->{transport} };
 
-    if (!defined($transport)) {
-        siplog("LOG_WARNING", "Unknown transport '%s', dropping", $service->{transport});
+    if ( !defined($transport) ) {
+        siplog( "LOG_WARNING", "Unknown transport '%s', dropping", $service->{transport} );
         return;
     } else {
         &$transport($self);
@@ -273,29 +279,32 @@ sub raw_transport {
     my $self = shift;
     my $input;
     my $service = $self->{service};
+
     # If using Net::Server::PreFork you may already have account set from a previous session
     # Ensure you dont
-    if ($self->{account}) {
+    if ( $self->{account} ) {
         delete $self->{account};
     }
 
     # Timeout the while loop if we get stuck in it
     # In practice it should only iterate once but be prepared
     local $SIG{ALRM} = sub { die 'raw transport Timed Out!' };
-    my $timeout = $self->get_timeout({ transport => 1 });
-    siplog('LOG_DEBUG', "raw_transport: timeout is $timeout");
+    my $timeout = $self->get_timeout( { transport => 1 } );
+    siplog( 'LOG_DEBUG', "raw_transport: timeout is $timeout" );
     alarm $timeout;
-    while (!$self->{account}) {
+    while ( !$self->{account} ) {
         $input = read_request();
-        if (!$input) {
+        if ( !$input ) {
+
             # EOF on the socket
-            siplog("LOG_INFO", "raw_transport: shutting down: EOF during login");
+            siplog( "LOG_INFO", "raw_transport: shutting down: EOF during login" );
             return;
         }
-        $input =~ s/[\r\n]+$//sm; # Strip off trailing line terminator(s)
+        $input =~ s/[\r\n]+$//sm;    # Strip off trailing line terminator(s)
         my $reg = qr/^${\(LOGIN)}/;
-        last if $input !~ $reg ||
-            C4::SIP::Sip::MsgType::handle($input, $self, LOGIN);
+        last
+            if $input !~ $reg
+            || C4::SIP::Sip::MsgType::handle( $input, $self, LOGIN );
     }
     alarm 0;
 
@@ -303,7 +312,7 @@ sub raw_transport {
         Koha::Logger->get(
             {
                 interface => 'sip',
-                category  => $self->{account}->{id}, # Add id to namespace
+                category  => $self->{account}->{id},    # Add id to namespace
             }
         )
     );
@@ -312,30 +321,31 @@ sub raw_transport {
     Koha::Logger->put_mdc( "accountid", $self->{account}->{id} );
     Koha::Logger->put_mdc( "peeraddr",  $self->{server}->{peeraddr} );
 
-    siplog("LOG_DEBUG", "raw_transport: uname/inst: '%s/%s'",
+    siplog(
+        "LOG_DEBUG", "raw_transport: uname/inst: '%s/%s'",
         $self->{account}->{id}          // 'undef',
         $self->{account}->{institution} // 'undef'
     );
-    if (! $self->{account}->{id}) {
-        siplog("LOG_ERR","Login failed shutting down");
+    if ( !$self->{account}->{id} ) {
+        siplog( "LOG_ERR", "Login failed shutting down" );
         return;
     }
 
     $self->sip_protocol_loop();
-    siplog("LOG_INFO", "raw_transport: shutting down");
+    siplog( "LOG_INFO", "raw_transport: shutting down" );
     return;
 }
 
 sub get_clean_string {
     my $string = shift;
-    if (defined $string) {
-        siplog("LOG_DEBUG", "get_clean_string  pre-clean(length %s): %s", length($string), $string);
+    if ( defined $string ) {
+        siplog( "LOG_DEBUG", "get_clean_string  pre-clean(length %s): %s", length($string), $string );
         chomp($string);
         $string =~ s/^[^A-z0-9]+//;
         $string =~ s/[^A-z0-9]+$//;
-        siplog("LOG_DEBUG", "get_clean_string post-clean(length %s): %s", length($string), $string);
+        siplog( "LOG_DEBUG", "get_clean_string post-clean(length %s): %s", length($string), $string );
     } else {
-        siplog("LOG_INFO", "get_clean_string called on undefined");
+        siplog( "LOG_INFO", "get_clean_string called on undefined" );
     }
     return $string;
 }
@@ -344,70 +354,73 @@ sub get_clean_input {
     local $/ = "\012";
     my $in = <STDIN>;
     $in = get_clean_string($in);
-    while (my $extra = <STDIN>){
-        siplog("LOG_ERR", "get_clean_input got extra lines: %s", $extra);
+    while ( my $extra = <STDIN> ) {
+        siplog( "LOG_ERR", "get_clean_input got extra lines: %s", $extra );
     }
     return $in;
 }
 
 sub telnet_transport {
     my $self = shift;
-    my ($uid, $pwd);
+    my ( $uid, $pwd );
     my $strikes = 3;
     my $account = undef;
     my $input;
     my $config  = $self->{config};
-    my $timeout = $self->get_timeout({ transport => 1 });
-    siplog("LOG_DEBUG", "telnet_transport: timeout is $timeout");
+    my $timeout = $self->get_timeout( { transport => 1 } );
+    siplog( "LOG_DEBUG", "telnet_transport: timeout is $timeout" );
 
     eval {
-    local $SIG{ALRM} = sub { die "telnet_transport: Timed Out ($timeout seconds)!\n"; };
-    local $| = 1;           # Unbuffered output
-    $/ = "\015";        # Internet Record Separator (lax version)
-    # Until the terminal has logged in, we don't trust it
-    # so use a timeout to protect ourselves from hanging.
+        local $SIG{ALRM} = sub { die "telnet_transport: Timed Out ($timeout seconds)!\n"; };
+        local $| = 1;                                                                          # Unbuffered output
+        $/ = "\015";    # Internet Record Separator (lax version)
+                        # Until the terminal has logged in, we don't trust it
+                        # so use a timeout to protect ourselves from hanging.
 
-    while ($strikes--) {
-        print "login: ";
-        alarm $timeout;
-        # $uid = &get_clean_input;
-        $uid = <STDIN>;
-        print "password: ";
-        # $pwd = &get_clean_input || '';
-        $pwd = <STDIN>;
-        alarm 0;
+        while ( $strikes-- ) {
+            print "login: ";
+            alarm $timeout;
 
-        siplog("LOG_DEBUG", "telnet_transport 1: uid length %s, pwd length %s", length($uid), length($pwd));
-        $uid = get_clean_string ($uid);
-        $pwd = get_clean_string ($pwd);
-        siplog("LOG_DEBUG", "telnet_transport 2: uid length %s, pwd length %s", length($uid), length($pwd));
+            # $uid = &get_clean_input;
+            $uid = <STDIN>;
+            print "password: ";
 
-        if (exists ($config->{accounts}->{$uid})
-        && ($pwd eq $config->{accounts}->{$uid}->{password})) {
-            $account = $config->{accounts}->{$uid};
-            if ( C4::SIP::Sip::MsgType::login_core($self,$uid,$pwd) ) {
-                last;
+            # $pwd = &get_clean_input || '';
+            $pwd = <STDIN>;
+            alarm 0;
+
+            siplog( "LOG_DEBUG", "telnet_transport 1: uid length %s, pwd length %s", length($uid), length($pwd) );
+            $uid = get_clean_string($uid);
+            $pwd = get_clean_string($pwd);
+            siplog( "LOG_DEBUG", "telnet_transport 2: uid length %s, pwd length %s", length($uid), length($pwd) );
+
+            if ( exists( $config->{accounts}->{$uid} )
+                && ( $pwd eq $config->{accounts}->{$uid}->{password} ) )
+            {
+                $account = $config->{accounts}->{$uid};
+                if ( C4::SIP::Sip::MsgType::login_core( $self, $uid, $pwd ) ) {
+                    last;
+                }
             }
+            siplog( "LOG_WARNING", "Invalid login attempt: '%s'", ( $uid || '' ) );
+            print("Invalid login$CRLF");
         }
-        siplog("LOG_WARNING", "Invalid login attempt: '%s'", ($uid||''));
-        print("Invalid login$CRLF");
-    }
-    }; # End of eval
+    };    # End of eval
 
     if ($@) {
-        siplog("LOG_ERR", "telnet_transport: Login timed out");
+        siplog( "LOG_ERR", "telnet_transport: Login timed out" );
         die "Telnet Login Timed out";
-    } elsif (!defined($account)) {
-        siplog("LOG_ERR", "telnet_transport: Login Failed");
+    } elsif ( !defined($account) ) {
+        siplog( "LOG_ERR", "telnet_transport: Login Failed" );
         die "Login Failure";
     } else {
         print "Login OK.  Initiating SIP$CRLF";
     }
 
     $self->{account} = $account;
-    siplog("LOG_DEBUG", "telnet_transport: uname/inst: '%s/%s'", $account->{id}, $account->{institution});
+    siplog( "LOG_DEBUG", "telnet_transport: uname/inst: '%s/%s'", $account->{id}, $account->{institution} );
     $self->sip_protocol_loop();
-    siplog("LOG_INFO", "telnet_transport: shutting down");
+    siplog( "LOG_INFO", "telnet_transport: shutting down" );
     return;
 }
 
@@ -417,10 +430,10 @@ sub telnet_transport {
 # telnet transport.  From that point on, both the raw and the telnet
 # processes are the same:
 sub sip_protocol_loop {
-    my $self = shift;
+    my $self    = shift;
     my $service = $self->{service};
     my $config  = $self->{config};
-    my $timeout = $self->get_timeout({ client => 1 });
+    my $timeout = $self->get_timeout( { client => 1 } );
 
     # The spec says the first message will be:
     #     SIP v1: SC_STATUS
@@ -474,41 +487,41 @@ sub sip_protocol_loop {
 }
 
 sub read_request {
-      my $raw_length;
-      local $/ = "\015";
+    my $raw_length;
+    local $/ = "\015";
 
-      # SIP connections might be active for weeks, clear L1 cache on every request
-      Koha::Caches->flush_L1_caches();
+    # SIP connections might be active for weeks, clear L1 cache on every request
+    Koha::Caches->flush_L1_caches();
 
     # proper SPEC: (octal) \015 = (hex) x0D = (dec) 13 = (ascii) carriage return
-      my $buffer = <STDIN>;
-      if ( defined $buffer ) {
-          STDIN->flush();    # clear an extra linefeed
-          chomp $buffer;
-          $raw_length = length $buffer;
-          $buffer =~ s/^\s*[^A-z0-9]+//s;
-# Every line must start with a "real" character.  Not whitespace, control chars, etc.
-          $buffer =~ s/[^A-z0-9]+$//s;
+    my $buffer = <STDIN>;
+    if ( defined $buffer ) {
+        STDIN->flush();    # clear an extra linefeed
+        chomp $buffer;
+        $raw_length = length $buffer;
+        $buffer =~ s/^\s*[^A-z0-9]+//s;
 
-# Same for the end.  Note this catches the problem some clients have sending empty fields at the end, like |||
-          $buffer =~ s/\015?\012//g;    # Extra line breaks must die
-          $buffer =~ s/\015?\012//s;    # Extra line breaks must die
-          $buffer =~ s/\015*\012*$//s;
+        # Every line must start with a "real" character.  Not whitespace, control chars, etc.
+        $buffer =~ s/[^A-z0-9]+$//s;
 
-    # treat as one line to include the extra linebreaks we are trying to remove!
-      }
-      else {
-          siplog( 'LOG_DEBUG', 'EOF returned on read' );
-          return;
-      }
-      my $len = length $buffer;
-      if ( $len != $raw_length ) {
-          my $trim = $raw_length - $len;
-          siplog( 'LOG_DEBUG', "read_request trimmed $trim character(s) " );
-      }
+        # Same for the end.  Note this catches the problem some clients have sending empty fields at the end, like |||
+        $buffer =~ s/\015?\012//g;     # Extra line breaks must die
+        $buffer =~ s/\015?\012//s;     # Extra line breaks must die
+        $buffer =~ s/\015*\012*$//s;
 
-      siplog( 'LOG_INFO', "INPUT MSG: '$buffer'" );
-      return $buffer;
+        # treat as one line to include the extra linebreaks we are trying to remove!
+    } else {
+        siplog( 'LOG_DEBUG', 'EOF returned on read' );
+        return;
+    }
+    my $len = length $buffer;
+    if ( $len != $raw_length ) {
+        my $trim = $raw_length - $len;
+        siplog( 'LOG_DEBUG', "read_request trimmed $trim character(s) " );
+    }
+
+    siplog( 'LOG_INFO', "INPUT MSG: '$buffer'" );
+    return $buffer;
 }
 
 # $server->get_timeout({ $type => 1, fallback => $fallback });
@@ -524,25 +537,27 @@ sub read_request {
 sub get_timeout {
     my ( $server, $params ) = @_;
     my $fallback = $params->{fallback} || 30;
-    my $service = $server->{service} // {};
-    my $config = $server->{config} // {};
+    my $service  = $server->{service} // {};
+    my $config   = $server->{config}  // {};
 
-    if( $params->{transport} ||
-        ( $params->{client} && !exists $service->{client_timeout} )) {
+    if ( $params->{transport}
+        || ( $params->{client} && !exists $service->{client_timeout} ) )
+    {
         # We do not allow zero values here.
         # Note: config/timeout seems to be deprecated.
         return $service->{timeout} || $config->{timeout} || $fallback;
 
-    } elsif( $params->{client} ) {
+    } elsif ( $params->{client} ) {
+
         # We know that client_timeout exists now.
         # We do allow zero values here to indicate no timeout.
         return 0 if $service->{client_timeout} =~ /^0+$|\D/;
         return $service->{client_timeout};
 
-    } elsif( $params->{policy} ) {
+    } elsif ( $params->{policy} ) {
         my $policy = $server->{policy} // {};
-        my $rv = sprintf( "%03d", $policy->{timeout} // 0 );
-        if( length($rv) != 3 ) {
+        my $rv     = sprintf( "%03d", $policy->{timeout} // 0 );
+        if ( length($rv) != 3 ) {
             siplog( "LOG_ERR", "Policy timeout has wrong size: '%s'", $rv );
             return '000';
         }
